@@ -24,3 +24,11 @@ class WebRunnerExecuteException(WebDriverException):
 
 class WebRunnerJsonException(WebDriverException):
     pass
+
+
+class AssertException(WebDriverException):
+    pass
+
+
+class HTMLException(WebDriverException):
+    pass
